<!--[metadata]>
+++
title = "Backups and disaster recovery"
description = "Learn how to backup your Docker Trusted Registry cluster, and to recover your cluster from an existing backup."
keywords = ["docker, registry, high-availability, backup, recovery"]
[menu.main]
parent="dtr_menu_high_availability"
identifier="dtr_backup_disaster_recovery"
weight=10
+++
<![end-metadata]-->


# Backups and disaster recovery

When you decide to start using Docker Trusted Registry on a production
setting, you should [configure it for high availability](high-availability.md).

The next step is creating a backup policy and disaster recovery plan.

## DTR data persistency

Docker Trusted Registry persists:

* Configurations: the cluster configurations are stored on a key-value store
that is replicated through all DTR replicas.
* Repository metadata: the information about the repositories and
images deployed. This information is replicated through all DTR replicas.
* Certificates and keys: the certificates, public keys, and private keys that
are used for mutual TLS communication.

This data is persisted on the host where DTR is running, using named volumes.
[Learn more about DTR named volumes](../architecture.md).

DTR also persists Docker images on the filesystem of the host running DTR, or
on a cloud provider, depending on the way DTR is configured.

## Backup DTR data

To perform a backup of a DTR node, use the `docker/dtr backup` command. This
command creates a backup of DTR:

* Configurations,
* Repository metadata,
* Certificates and keys used by DTR.

These files are added to a tar archive, and the result is streamed to stdout.

The backup command does not create a backup of Docker images. You should
implement a separate backup policy for the Docker images, taking in
consideration whether your DTR installation is configured to store images on the
filesystem or using a cloud provider.

When creating a backup, the resulting .tar file contains sensitive information
like private keys. You should ensure the backups are stored securely.

To learn about the options available on the backup command, you can
[check the reference documentation](../reference/backup.md), or run:

```bash
$ docker run --rm -it docker/dtr backup --help
```

As an example, to create a backup of a DTR node, you can use:

```bash
# Get the certificates used by UCP
$ curl https://$UCP_HOST/ca > ucp-ca.pem

# Create the backup
$ docker run -it --rm docker/dtr backup \
  --ucp-ca "$(cat ucp-ca.pem)" \
  --replica-id 8b6174866010 \
  --ucp-username $UCP_ADMIN --ucp-password $UCP_PASSWORD \
  --ucp-url $UCP_HOST > /tmp/backup.tar
```

Where:

* --ucp-ca is the certificate used by UCP,
* --replica-id is the name of the replica to backup,
* --ucp-username, and --ucp-password are the credentials of a UCP administrator,
* --ucp-url is the address of UCP.

## Restore DTR data

You can restore a DTR node from a backup using the `docker/dtr restore`
command.
This command performs a fresh installation of DTR, and reconfigures it with
the configuration created during a backup.

The command starts by installing DTR, restores the configurations stored on
etcd, and then restores the repository metadata stored on RethinkDB. You
can use the `--config-only` option, to only restore the configurations stored
on etcd.

This command does not restore Docker images. You should implement a separate
restore procedure for the Docker images stored in your registry, taking in
consideration whether your DTR installation is configured to store images on
the filesystem or using a cloud provider.

To learn about the options available on the restore command, you can
[check the reference documentation](../reference/restore.md), or run:

```bash
$ docker run --rm -it docker/trusted-registry restore --help
```

As an example, to install DTR on the host at 192.168.10.100, and restore its
state from an existing backup:

```bash
# Get the certificates used by UCP
$ curl https://$UCP_HOST/ca > ucp-ca.pem

# Install and restore configurations from an existing backup
$ docker run -i --rm \
  -v /var/run/docker.sock:/var/run/docker.sock \
  docker/dtr restore \
  --ucp-ca "$(cat ucp-ca.pem)" \  
  --ucp-username $UCP_ADMIN --ucp-password $UCP_PASSWORD \
  --ucp-url $UCP_HOST --dtr-load-balancer 192.168.10.100 < /tmp/backup.tar
```

Where:

* --ucp-ca is the certificate used by UCP,
* --ucp-username, and --ucp-password are the credentials of a UCP administrator,
* --ucp-url is the address of UCP,
* --dtr-load-balancer is the host to where DTR will be installed.


## Where to go next

* [Set up high availability](high-availability.md)
* [DTR architecture](../architecture.md)
